@@ -25,9 +25,10 @@ from torch.nn.utils import clip_grad_norm_
 from torch.cuda.amp import GradScaler
 from torch.utils.data import DataLoader, Dataset
 
-from dstk.pytorch import (check_tensor, CallbackInterface, CallbackHandler,
-                          FitState, FitControl, is_dist_avail_and_initialized,
-                          DEFAULT_CALLBACKS)
+from dstk.pytorch._utils import check_tensor, is_dist_avail_and_initialized
+from dstk.pytorch._callback import (CallbackInterface, CallbackHandler,
+                                    FitState, FitControl, PrintCallback,
+                                    ProgressBarCallback, EarlyStoppingCallback)
 from dstk.utils.errors import DivergenceError
 
 
@@ -550,7 +551,7 @@ class BaseEnvironnement(BaseEstimator):
         optimizer_kargs: Dict[str, any]=dict(),
         nb_epoch: int,
         iter_eval: Optional[int]=None,
-        callbacks: List[CallbackInterface]=DEFAULT_CALLBACKS,
+        callbacks: Optional[List[CallbackInterface]]=None,
         device: str='cuda:0',
         mixed_type_gpu: bool=False,
         expected_key_to_device: List[str]=list(),
@@ -616,12 +617,11 @@ class BaseEnvironnement(BaseEstimator):
             défaut) les évaluations du modèle seront à la fin des époques. 
             Si un entier positif est renseigné les évaluations auront lieu 
             tous les iter_eval itérations d'apprentissage.
-        callbacks : List[CallbackInterface] (=DEFAULT_CALLBACKS)
+        callbacks : Optional[List[CallbackInterface]]
             Liste de callback intervenant aux différentes étapes de 
             l'entraînement et de l'évaluation. Pour avoir la liste des 
             différents callbacks implémentés par défaut voir 
-            :func:`~dstk.pytorch._callback`. Par défaut utilise les 
-            DEFAULT_CALLBACKS.
+            :func:`~dstk.pytorch._callback`.
         device : str (='cuda:0')
             Indique le device sur le quel l'apprentissage s'exécute.
         mixed_type_gpu : bool (=False)
