@@ -18,6 +18,9 @@ from torch.nn import Module, SyncBatchNorm, parallel
 from torch.utils.data import Dataset, DataLoader
 from torch.utils.data.distributed import DistributedSampler
 
+from dstk.pytorch._utils import is_dist_avail_and_initialized
+from dstk.pytorch._base import BaseEnvironnement
+
 
 def is_main_process():
     r"""
@@ -35,22 +38,6 @@ def get_rank():
     return dist.get_rank()
 
 
-def is_dist_avail_and_initialized():
-    r"""
-    Détermine si on est dans la cas d'un process distribué ou non.
-    """
-    if not dist.is_available():
-        return False
-
-    if not dist.is_initialized():
-        return False
-
-    # if not dist.is_torchelastic_launched():
-    #     return False
-
-    return True
-
-
 def save_on_master(*args, **kwargs):
     r"""
     Permet de sauvegarder via torch.save sur le device maître.
@@ -97,6 +84,43 @@ def init_distributed(dist_url: str = "env://", backend: str = "nccl"):
     return local_rank
 
 
+class DistributedDataParallel(
+    parallel.DistributedDataParallel,
+    BaseEnvironnement
+):
+    r"""
+    Classe interface à torch.nn.parallel.DistributedDataParallel. Pour
+    connaitre les arguements de cette classe ce référer à la doc PyTorch.
+    """
+    def __init__(
+        self,
+        module,
+        device_ids=None,
+        output_device=None,
+        dim=0,
+        broadcast_buffers=True,
+        process_group=None,
+        bucket_cap_mb=25,
+        find_unused_parameters=False,
+        check_reduction=False,
+        gradient_as_bucket_view=False,
+        static_graph=False,
+    ):
+        super().__init__(
+            module=module,
+            device_ids=device_ids,
+            output_device=output_device,
+            dim=dim,
+            broadcast_buffers=broadcast_buffers,
+            process_group=process_group,
+            bucket_cap_mb=bucket_cap_mb,
+            find_unused_parameters=find_unused_parameters,
+            check_reduction=check_reduction,
+            gradient_as_bucket_view=gradient_as_bucket_view,
+            static_graph=static_graph,
+        )
+
+
 def auto_init_distributed(
     model: Module,
     train_dataset: Dataset,
@@ -166,7 +190,7 @@ def auto_init_distributed(
 
     model = model.cuda()
     model = SyncBatchNorm.convert_sync_batchnorm(model)
-    model = parallel.DistributedDataParallel(model, device_ids=[local_rank])
+    model = DistributedDataParallel(model, device_ids=[local_rank])
     shuffle = None
     drop_last = None
     if 'shuffle' in kwargs_train_dataloader:
